@@ -13,10 +13,8 @@ $ hpccm.py --recipe recipes/examples/userargs.py --userarg cuda=9.0 ompi=2.1.2
 cuda_version = USERARG.get('cuda', '9.1')
 image = 'nvcr.io/nvidia/cuda:{}-devel-ubuntu16.04'.format(cuda_version)
 
-Stage0.baseimage(image)
+Stage0 += baseimage(image=image)
 
 # Set the OpenMPI version based on the specified version (default to 3.0.0)
 ompi_version = USERARG.get('ompi', '3.0.0')
-ompi = openmpi(infiniband=False, version=ompi_version)
-
-Stage0 += ompi
+Stage0 += openmpi(infiniband=False, version=ompi_version)
